@@ -9,7 +9,7 @@ api_accounts <- function(RH) {
 
   # URL and token
   url <- RobinHood::api_endpoints("accounts")
-  token <- paste("Bearer", RH$tokens.access_token)
+  token <- paste("Bearer", RH$api_response.access_token)
 
   # GET call
   dta <- GET(url,
