@@ -11,7 +11,7 @@ api_historicals <- function(RH, historicals_url, body) {
 
   # URL and token
   url <- paste(historicals_url, "?", body, sep = "")
-  token <- paste("Bearer", RH$tokens.access_token)
+  token <- paste("Bearer", RH$api_response.access_token)
 
   # GET call
   dta <- GET(url,
