@@ -9,7 +9,7 @@
 api_historicals_crypto <- function(RH, url) {
 
   # url to get historical data
-  token <- paste("Bearer", RH$tokens.access_token)
+  token <- paste("Bearer", RH$api_response.access_token)
 
   # GET call
   dta <- GET(url,
