@@ -16,7 +16,7 @@ api_marketdata <- function(RH, instrument, type = "instrument_id") {
   }
 
   # Token
-  token <- paste("Bearer", RH$tokens.access_token)
+  token <- paste("Bearer", RH$api_response.access_token)
 
   # GET call
   dta <- GET(url,
