@@ -11,7 +11,7 @@ api_portfolios_crypto <- function(RH) {
   url <- paste(api_endpoints("portfolios", source = "crypto"),
                api_accounts_crypto(RH)$id, "/",
                sep = "")
-  token <- paste("Bearer", RH$tokens.access_token)
+  token <- paste("Bearer", RH$api_response.access_token)
 
   # GET call
   dta <- GET(url,
