@@ -5,6 +5,6 @@
 check_rh <- function(RH) {
 
     # Check if RH is the correct class
-    if (class(RH) != "RobinHood") stop("RH must be class RobinHood, see RobinHood()")
+    if (methods::is(RH) != "RobinHood") stop("RH must be class RobinHood, see RobinHood()")
 
 }
